@@ -1,6 +1,6 @@
 from typing import Iterable
 
-import torch
+import numpy as np
 
 from cca_zoo.deepmodels import objectives
 from cca_zoo.deepmodels.architectures import BaseEncoder, Encoder
@@ -8,10 +8,12 @@ from cca_zoo.deepmodels.dcca import DCCA
 from cca_zoo.models import TCCA
 
 
-class DTCCA(DCCA, torch.nn.Module):
+class DTCCA(DCCA):
     """
     A class used to fit a DTCCA model.
 
+    Is just a thin wrapper round DCCA with the DTCCA objective and a TCCA post-processing
+
     Examples
     --------
     >>> from cca_zoo.deepmodels import DTCCA
@@ -19,21 +21,18 @@ class DTCCA(DCCA, torch.nn.Module):
     """
 
     def __init__(self, latent_dims: int, encoders: Iterable[BaseEncoder] = [Encoder, Encoder],
-                 learning_rate=1e-3, r: float = 0,
-                 schedulers: Iterable = None, optimizers: Iterable = None):
+                 r: float = 1e-7, eps: float = 1e-7):
         """
 
-        :param latent_dims:
-        :param encoders:
-        :param learning_rate:
-        :param r:
-        :param schedulers:
-        :param optimizers:
+        :param latent_dims: # latent dimensions
+        :param encoders: list of encoder networks
+        :param r: regularisation parameter of tracenorm CCA like ridge CCA. Needs to be VERY SMALL. If you get errors make this smaller
+        :param eps: epsilon used throughout. Needs to be VERY SMALL. If you get errors make this smaller
         """
-        super().__init__(latent_dims, objective=objectives.TCCA, encoders=encoders, learning_rate=learning_rate, r=r,
-                         schedulers=schedulers, optimizers=optimizers)
+        super().__init__(latent_dims=latent_dims, objective=objectives.TCCA, encoders=encoders, r=r,
+                         eps=eps)
 
-    def post_transform(self, *z_list, train=False):
+    def post_transform(self, *z_list, train=False) -> Iterable[np.ndarray]:
         if train:
             self.cca = TCCA(latent_dims=self.latent_dims)
             self.cca.fit(*z_list)
