@@ -1,7 +1,7 @@
 from unittest import TestCase
 
-import numpy as np
-from torch import optim
+from sklearn.utils.validation import check_random_state
+from torch import optim, manual_seed
 
 from cca_zoo import data
 from cca_zoo.deepmodels import DCCA, DCCAE, DVCCA, DCCA_NOI, DTCCA, SplitAE, DeepWrapper
@@ -11,11 +11,13 @@ from cca_zoo.deepmodels import objectives, architectures
 class TestDeepModels(TestCase):
 
     def setUp(self):
-        self.X = np.random.rand(200, 10)
-        self.Y = np.random.rand(200, 10)
-        self.Z = np.random.rand(200, 10)
-        self.X_conv = np.random.rand(100, 1, 16, 16)
-        self.Y_conv = np.random.rand(100, 1, 16, 16)
+        manual_seed(0)
+        self.rng = check_random_state(0)
+        self.X = self.rng.rand(200, 10)
+        self.Y = self.rng.rand(200, 10)
+        self.Z = self.rng.rand(200, 10)
+        self.X_conv = self.rng.rand(100, 1, 16, 16)
+        self.Y_conv = self.rng.rand(100, 1, 16, 16)
         self.train_dataset = data.CCA_Dataset(self.X, self.Y)
 
     def tearDown(self):
@@ -34,6 +36,19 @@ class TestDeepModels(TestCase):
         dcca_model.fit(self.train_dataset, epochs=3)
         dcca_model.fit(self.train_dataset, val_dataset=self.train_dataset, epochs=3)
         dcca_model.fit((self.X, self.Y), val_dataset=(self.X, self.Y), epochs=3)
+        dcca_model.fit((self.X, self.Y), val_split=0.2, epochs=3)
+
+    def test_large_p(self):
+        X = self.rng.rand(2000, 2048)
+        Y = self.rng.rand(2000, 2048)
+        latent_dims = 150
+        device = 'cpu'
+        encoder_1 = architectures.Encoder(latent_dims=latent_dims, feature_size=2048)
+        encoder_2 = architectures.Encoder(latent_dims=latent_dims, feature_size=2048)
+        dcca_model = DCCA(latent_dims=latent_dims, encoders=[encoder_1, encoder_2],
+                          objective=objectives.CCA)
+        dcca_model = DeepWrapper(dcca_model, device=device)
+        dcca_model.fit((X, Y), epochs=10)
 
     def test_DCCA_methods_cpu(self):
         latent_dims = 2
@@ -45,24 +60,24 @@ class TestDeepModels(TestCase):
                           objective=objectives.CCA)
         # hidden_layer_sizes are shown explicitly but these are also the defaults
         dcca_model = DeepWrapper(dcca_model, device=device)
-        dcca_model.fit((self.X, self.Y), epochs=10)
+        dcca_model.fit((self.X, self.Y), epochs=20)
         # DGCCA
         dgcca_model = DCCA(latent_dims=latent_dims, encoders=[encoder_1, encoder_2],
                            objective=objectives.GCCA)
         # hidden_layer_sizes are shown explicitly but these are also the defaults
         dgcca_model = DeepWrapper(dgcca_model, device=device)
-        dgcca_model.fit((self.X, self.Y), epochs=3)
+        dgcca_model.fit((self.X, self.Y), epochs=20)
         # DMCCA
         dmcca_model = DCCA(latent_dims=latent_dims, encoders=[encoder_1, encoder_2],
                            objective=objectives.MCCA)
         # hidden_layer_sizes are shown explicitly but these are also the defaults
         dmcca_model = DeepWrapper(dmcca_model, device=device)
-        dmcca_model.fit((self.X, self.Y), epochs=3)
+        dmcca_model.fit((self.X, self.Y), epochs=20)
         # DCCA_NOI
         dcca_noi_model = DCCA_NOI(latent_dims, self.X.shape[0], encoders=[encoder_1, encoder_2])
         # hidden_layer_sizes are shown explicitly but these are also the defaults
         dcca_noi_model = DeepWrapper(dcca_noi_model, device=device)
-        dcca_noi_model.fit((self.X, self.Y), epochs=30)
+        dcca_noi_model.fit((self.X, self.Y), epochs=20)
 
     def test_DTCCA_methods_cpu(self):
         latent_dims = 2
@@ -76,26 +91,24 @@ class TestDeepModels(TestCase):
         dtcca_model = DeepWrapper(dtcca_model, device=device)
         dtcca_model.fit((self.X, self.Y), epochs=20)
         # DCCA
-        dcca_model = DCCA(latent_dims=latent_dims, encoders=[encoder_1, encoder_2, encoder_3],
+        dcca_model = DCCA(latent_dims=latent_dims, encoders=[encoder_1, encoder_2],
                           objective=objectives.GCCA)
         # hidden_layer_sizes are shown explicitly but these are also the defaults
         dcca_model = DeepWrapper(dcca_model, device=device)
-        dcca_model.fit((self.X, self.Y, self.Z), epochs=20)
-        print('here')
+        dcca_model.fit((self.X, self.Y), epochs=20)
 
-    def test_schedulers(self):
+    def test_scheduler(self):
         latent_dims = 2
         device = 'cpu'
         encoder_1 = architectures.Encoder(latent_dims=latent_dims, feature_size=10)
         encoder_2 = architectures.Encoder(latent_dims=latent_dims, feature_size=10)
         # DCCA
-        optimizers = [optim.Adam(encoder_1.parameters(), lr=1e-4), optim.Adam(encoder_2.parameters(), lr=1e-4)]
-        schedulers = [optim.lr_scheduler.CosineAnnealingLR(optimizers[0], 1),
-                      optim.lr_scheduler.ReduceLROnPlateau(optimizers[1])]
         dcca_model = DCCA(latent_dims=latent_dims, encoders=[encoder_1, encoder_2],
-                          objective=objectives.CCA, optimizers=optimizers, schedulers=schedulers)
+                          objective=objectives.CCA)
+        optimizer = optim.Adam(dcca_model.parameters(), lr=1e-4)
+        scheduler = optim.lr_scheduler.CosineAnnealingLR(optimizer, 1)
         # hidden_layer_sizes are shown explicitly but these are also the defaults
-        dcca_model = DeepWrapper(dcca_model, device=device)
+        dcca_model = DeepWrapper(dcca_model, device=device, optimizer=optimizer, scheduler=scheduler)
         dcca_model.fit((self.X, self.Y), epochs=20)
 
     def test_DGCCA_methods_cpu(self):
@@ -180,7 +193,7 @@ class TestDeepModels(TestCase):
         decoder_1 = architectures.Decoder(latent_dims=2 * latent_dims, feature_size=10, norm_output=True)
         decoder_2 = architectures.Decoder(latent_dims=2 * latent_dims, feature_size=10, norm_output=True)
         # DVCCA
-        dvcca_model = DVCCA(latent_dims=latent_dims, private=True, encoders=[encoder_1, encoder_2],
+        dvcca_model = DVCCA(latent_dims=latent_dims, encoders=[encoder_1, encoder_2],
                             decoders=[decoder_1, decoder_2],
                             private_encoders=[private_encoder_1, private_encoder_2])
         # hidden_layer_sizes are shown explicitly but these are also the defaults
